Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3823)

Unified Diff: chrome/common/importer/importer_test_registry_overrider_win.h

Issue 1465853002: Implement support for importing favorites from Edge on Windows 10. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Added missing include files Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/common/importer/importer_test_registry_overrider_win.h
diff --git a/chrome/common/importer/ie_importer_test_registry_overrider_win.h b/chrome/common/importer/importer_test_registry_overrider_win.h
similarity index 56%
rename from chrome/common/importer/ie_importer_test_registry_overrider_win.h
rename to chrome/common/importer/importer_test_registry_overrider_win.h
index de86e7ee1abc8356d410637f2e0e99bf4bd23af3..4f493fc20f49f5f468a38489621144631ae3bb52 100644
--- a/chrome/common/importer/ie_importer_test_registry_overrider_win.h
+++ b/chrome/common/importer/importer_test_registry_overrider_win.h
@@ -2,24 +2,24 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_COMMON_IMPORTER_IE_IMPORTER_TEST_REGISTRY_OVERRIDER_WIN_H_
-#define CHROME_COMMON_IMPORTER_IE_IMPORTER_TEST_REGISTRY_OVERRIDER_WIN_H_
+#ifndef CHROME_COMMON_IMPORTER_IMPORTER_TEST_REGISTRY_OVERRIDER_WIN_H_
+#define CHROME_COMMON_IMPORTER_IMPORTER_TEST_REGISTRY_OVERRIDER_WIN_H_
#include "base/basictypes.h"
#include "base/strings/string16.h"
// A helper class to let tests generate a random registry key to be used in
// HKEY_CURRENT_USER in tests. After the key has been generated by constructing
// an IEImporterTestRegistryOverrider, consumers in this process (or in any
// child processes created after the key has been generated) can obtain the key
// via GetTestRegistryOverride(). IEImporterTestRegistryOverrider will delete
// the temporary key upon being deleted itself. Only one
// IEImporterTestRegistryOverrider should live at once in a given process
// hiearchy.
-class IEImporterTestRegistryOverrider {
+class ImporterTestRegistryOverrider {
public:
- IEImporterTestRegistryOverrider();
- ~IEImporterTestRegistryOverrider();
+ ImporterTestRegistryOverrider();
+ ~ImporterTestRegistryOverrider();
// Returns a test key if one was chosen and set by a call to
// SetTestRegistryOverride(); returns the empty string if none.
@@ -28,7 +28,7 @@ class IEImporterTestRegistryOverrider {
private:
base::string16 temporary_key_;
- DISALLOW_COPY_AND_ASSIGN(IEImporterTestRegistryOverrider);
+ DISALLOW_COPY_AND_ASSIGN(ImporterTestRegistryOverrider);
};
-#endif // CHROME_COMMON_IMPORTER_IE_IMPORTER_TEST_REGISTRY_OVERRIDER_WIN_H_
+#endif // CHROME_COMMON_IMPORTER_IMPORTER_TEST_REGISTRY_OVERRIDER_WIN_H_

Powered by Google App Engine
This is Rietveld 408576698
@@ -2,24 +2,24 @@
// A helper class to let tests generate a random registry key to be used in
// HKEY_CURRENT_USER in tests. After the key has been generated by constructing
-// an IEImporterTestRegistryOverrider, consumers in this process (or in any
+// an ImporterTestRegistryOverrider, consumers in this process (or in any
// child processes created after the key has been generated) can obtain the key
@@ -2,24 +2,24 @@
// child processes created after the key has been generated) can obtain the key
-// via GetTestRegistryOverride(). IEImporterTestRegistryOverrider will delete
+// via GetTestRegistryOverride(). ImporterTestRegistryOverrider will delete
// the temporary key upon being deleted itself. Only one
@@ -2,24 +2,24 @@
// the temporary key upon being deleted itself. Only one
-// IEImporterTestRegistryOverrider should live at once in a given process
+// ImporterTestRegistryOverrider should live at once in a given process
// hiearchy.